﻿''' <summary>
''' This is a simple programming example created in Visual Basic 2010 which is designed for interfacing with the USB port on the LabMax
''' meters. The LabMaxLowLevCtl has to be added to this project to interface with the meter. To add the LabMaxLowLevCtl to Visual Basic,
''' select "Tools > Choose Toolbox Items" from the menu bar in Visual Studio. Select the "COM Components" tab. Scroll down to locate
''' the "CLabMaxLowLevCtl Object". (This will be installed on the computer along with the USB drivers when the LabMax software is installed.)
''' Check the box next to "CLabMaxLowLevCtl Object" and press "OK". If this object does not show up in this list, you may have to browse
''' to find it at the following location: "C:\Windows\System32\LabMaxLowLevelControl.ocx". If the file does not show up there, you may have to
''' reinstall the LabMax software to make it available. Once this object is added to Visual Studio, you should be able to drag it from
''' the Toolbox and add it to the program, as shown in this example. This will add the necessary references to the program.
''' 
''' For controlling features of the LabMax, most of that is done using ASCII commands similar to the "DISP:BACK ON" command used to turn
''' the backlight on in this example. These commands are all listed in the user manual for the LabMax meters. Once a connection is established
''' with the LabMax meter, those ASCII commands can be sent to and received from the meter to control most features and collect data. The
''' "Transmit" and "Receive" controls in this example program can help test the ASCII commands from the LabMax user manual.
''' </summary>
''' <remarks></remarks>

Public Class Form1

    Dim PreviousIndex As Integer = 0 ' This variable will be used to turn off data streaming when switching to a different meter.

    Private Sub Form1_Load(sender As System.Object, e As System.EventArgs) Handles MyBase.Load
        ' Initializes communication upon form load.
        AxCLabMaxLowLevCtl1.Initialize()
        ' Establishes a connection through the USB port.
        AxCLabMaxLowLevCtl1.CommunicationMode = LabMaxLowLevelControl.LabMaxCommunicationMode.COM_MODE_USB
        ' Checks the serial number of the meter at the default index (0).
        If AxCLabMaxLowLevCtl1.get_SerialNumber(numMeterIndex.Value) <> Nothing Then
            lblSerialNum.Text = "Serial Number: " & AxCLabMaxLowLevCtl1.get_SerialNumber(numMeterIndex.Value)
        Else
            lblSerialNum.Text = "No meter connected at this index."
        End If
        ' Defaults the Streaming Mode to "off" when the form loads.
        radStreamOff.Checked = True
    End Sub

    Private Sub Form1_FormClosing(sender As Object, e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
        ' Makes sure Streaming Mode is turned off.
        AxCLabMaxLowLevCtl1.SendCommandOrQuery(numMeterIndex.Value, "SYST:COMM:USB:STRE OFF")
        ' Deinitializes communication upon form close.
        AxCLabMaxLowLevCtl1.DeInitialize()
    End Sub

    Private Sub AxCLabMaxLowLevCtl1_MeterAdded(sender As Object, e As AxLabMaxLowLevelControl._ILabMaxLowLevCtlEvents_MeterAddedEvent) Handles AxCLabMaxLowLevCtl1.MeterAdded
        ' Checks the serial number of the connected meter each time a meter is added.
        If AxCLabMaxLowLevCtl1.get_SerialNumber(numMeterIndex.Value) <> Nothing Then
            lblSerialNum.Text = "Serial Number: " & AxCLabMaxLowLevCtl1.get_SerialNumber(numMeterIndex.Value)
        Else
            lblSerialNum.Text = "No meter connected at this index."
        End If
    End Sub

    Private Sub AxCLabMaxLowLevCtl1_MeterRemoved(sender As Object, e As AxLabMaxLowLevelControl._ILabMaxLowLevCtlEvents_MeterRemovedEvent) Handles AxCLabMaxLowLevCtl1.MeterRemoved
        ' Displays a message if a meter is removed.
        MsgBox("Meter Removed")
    End Sub

    Private Sub numMeterIndex_ValueChanged(sender As System.Object, e As System.EventArgs) Handles numMeterIndex.ValueChanged
        ' Checks the serial number of the connected meter each time the meter index is changed.
        If AxCLabMaxLowLevCtl1.get_SerialNumber(numMeterIndex.Value) <> Nothing Then
            lblSerialNum.Text = "Serial Number: " & AxCLabMaxLowLevCtl1.get_SerialNumber(numMeterIndex.Value)
        Else
            lblSerialNum.Text = "No meter connected at this index."
        End If

        ' Turns off data streaming when switching to a new meter. (Otherwise you can get data streaming from multiple meters into the same field.)
        AxCLabMaxLowLevCtl1.SendCommandOrQuery(PreviousIndex, "SYST:COMM:USB:STRE OFF")
        radStreamOff.Checked = True
        PreviousIndex = numMeterIndex.Value
    End Sub

    Private Sub btnSend_Click(sender As System.Object, e As System.EventArgs) Handles btnSend.Click
        ' Sends a command to the meter and reads the reply.
        AxCLabMaxLowLevCtl1.SendCommandOrQuery(numMeterIndex.Value, txtTransmit.Text)
        txtReceive.AppendText(AxCLabMaxLowLevCtl1.GetNextString(numMeterIndex.Value) & vbCrLf)
    End Sub

    Private Sub btnClear_Click(sender As System.Object, e As System.EventArgs) Handles btnClear.Click
        ' Clears the textbox used to display replies.
        txtReceive.Clear()
    End Sub

    Private Sub btnBacklight_Click(sender As System.Object, e As System.EventArgs) Handles btnBacklight.Click
        ' Turns the meter's backlight either on or off.
        ' Checks the current state of the backlight and assigns that state to the Reply variable.
        Dim Reply As String
        AxCLabMaxLowLevCtl1.SendCommandOrQuery(numMeterIndex.Value, "DISP:BACK?")
        Reply = AxCLabMaxLowLevCtl1.GetNextString(numMeterIndex.Value)

        ' Switches the backlight to the opposite state.
        If Reply = "OFF" Then
            AxCLabMaxLowLevCtl1.SendCommandOrQuery(numMeterIndex.Value, "DISP:BACK ON")
        Else
            AxCLabMaxLowLevCtl1.SendCommandOrQuery(numMeterIndex.Value, "DISP:BACK OFF")
        End If
    End Sub

    Private Sub btnBuffer_Click(sender As System.Object, e As System.EventArgs) Handles btnBuffer.Click
        ' Initializes the meter's buffer to collect data.
        ' This first command sets the meter's buffer so that it only stores the most recent data point that was collected.
        AxCLabMaxLowLevCtl1.SendCommandOrQuery(numMeterIndex.Value, "CONF:READ:CONT LAST")
        ' This next command initializes the buffer so that it'll start capturing new data.
        AxCLabMaxLowLevCtl1.SendCommandOrQuery(numMeterIndex.Value, "INIT")
    End Sub

    Private Sub btnDataPoint_Click(sender As System.Object, e As System.EventArgs) Handles btnDataPoint.Click
        ' Queries the meter for the next available data point from the buffer.
        AxCLabMaxLowLevCtl1.SendCommandOrQuery(numMeterIndex.Value, "FETC:NEXT?")
        txtDataSingle.Text = AxCLabMaxLowLevCtl1.GetNextString(numMeterIndex.Value)
    End Sub

    Private Sub radStreamOn_CheckedChanged(sender As System.Object, e As System.EventArgs) Handles radStreamOn.CheckedChanged
        ' Turns the streaming mode on or off.
        If radStreamOn.Checked = True Then
            AxCLabMaxLowLevCtl1.SendCommandOrQuery(numMeterIndex.Value, "SYST:COMM:USB:STRE ON")
        Else
            AxCLabMaxLowLevCtl1.SendCommandOrQuery(numMeterIndex.Value, "SYST:COMM:USB:STRE OFF")
        End If
    End Sub

    Private Sub AxCLabMaxLowLevCtl1_USBStreamingPacket(sender As Object, e As AxLabMaxLowLevelControl._ILabMaxLowLevCtlEvents_USBStreamingPacketEvent) Handles AxCLabMaxLowLevCtl1.USBStreamingPacket
        ' Displays the streaming measurement value.
        txtDataStream.Text = e.iStreamingPacket(0)
    End Sub

End Class
